@@ -24,6 +24,16 @@ test_that("Plot works for Data object with placebo, blinding and no legend", {
   )
 })
 
+test_that("Plot works for Data object with response and backfill markers", {
+  data <- h_get_data()
+  result <- plot(data, mark_response = TRUE, mark_backfill = TRUE)
+
+  expect_doppel(
+    "Plot of Data with response and backfill markers",
+    result
+  )
+})
+
 # plot-DataDual ----
 
 test_that("Plot works as expected for DataDual object with placebo", {
@@ -98,6 +108,8 @@ test_that("Update of Data works as expected", {
   object@ID <- c(object@ID, 13L, 14L, 15L)
   object@xLevel <- c(object@xLevel, 2L, 2L, 2L)
   object@cohort <- c(object@cohort, 4L, 4L, 4L)
+  object@response <- c(object@response, NA, NA, NA)
+  object@backfilled <- c(object@backfilled, FALSE, FALSE, FALSE)
 
   expect_valid(result, "Data")
   expect_identical(result, object)
@@ -133,6 +145,8 @@ test_that("Update of Data works when doses are added to the old cohort", {
   object@ID <- c(object@ID, 13L, 14L, 15L)
   object@xLevel <- c(object@xLevel, 5L, 5L, 5L)
   object@cohort <- c(object@cohort, 3L, 3L, 3L)
+  object@response <- c(object@response, NA, NA, NA)
+  object@backfilled <- c(object@backfilled, FALSE, FALSE, FALSE)
 
   expect_valid(result, "Data")
   expect_identical(result, object)
@@ -159,7 +173,49 @@ test_that("Update of Data, no error for non-valid update and validation off", {
   )
 })
 
-# update-DataOrdinal
+test_that("update of Data object with backfill patients works", {
+  object <- h_get_data()
+  expect_identical(
+    object@cohort,
+    c(1L, 1L, 1L, 1L, 2L, 2L, 2L, 2L, 3L, 3L, 3L, 3L)
+  )
+  result <- update(
+    object,
+    x = 50,
+    y = c(0L, 1L),
+    backfill = TRUE,
+    cohort = 2L
+  )
+  expect_valid(result, "Data")
+  # Note that the backfill patients are sorted into the
+  # existing cohort 2:
+  expect_identical(
+    result@cohort,
+    c(1L, 1L, 1L, 1L, 2L, 2L, 2L, 2L, 2L, 2L, 3L, 3L, 3L, 3L)
+  )
+  expect_identical(
+    result@backfilled,
+    c(
+      FALSE,
+      FALSE,
+      TRUE,
+      TRUE,
+      FALSE,
+      FALSE,
+      TRUE,
+      TRUE,
+      TRUE,
+      TRUE,
+      FALSE,
+      FALSE,
+      TRUE,
+      TRUE
+    )
+  )
+})
+
+# update-DataOrdinal ----
+
 test_that("Update of Data works as expected", {
   object <- h_get_data()
   result <- update(object, x = 25, y = c(0L, 1L, 1L))
@@ -170,6 +226,8 @@ test_that("Update of Data works as expected", {
   object@ID <- c(object@ID, 13L, 14L, 15L)
   object@xLevel <- c(object@xLevel, 2L, 2L, 2L)
   object@cohort <- c(object@cohort, 4L, 4L, 4L)
+  object@response <- c(object@response, NA, NA, NA)
+  object@backfilled <- c(object@backfilled, FALSE, FALSE, FALSE)
 
   expect_valid(result, "Data")
   expect_identical(result, object)
@@ -245,6 +303,8 @@ test_that("Update of DataParts works as expected", {
   object@cohort <- c(object@cohort, 4L, 4L)
   object@part <- c(object@part, 1L, 1L)
   object@nextPart <- 2L
+  object@response <- c(object@response, NA, NA)
+  object@backfilled <- c(object@backfilled, FALSE, FALSE)
 
   expect_valid(result, "DataParts")
   expect_identical(result, object)
@@ -263,6 +323,8 @@ test_that("Update of DataParts works as expected", {
   object@cohort <- c(object@cohort, 4L, 4L)
   object@part <- c(object@part, 1L, 1L)
   object@nextPart <- 2L
+  object@response <- c(object@response, NA, NA)
+  object@backfilled <- c(object@backfilled, FALSE, FALSE)
 
   expect_valid(result, "DataParts")
   expect_identical(result, object)
@@ -283,6 +345,8 @@ test_that("Update of DataParts works, no DLT and x eq max of part1Ladder", {
   object@cohort <- c(object@cohort, 4L, 4L)
   object@part <- c(object@part, 1L, 1L)
   object@nextPart <- 2L
+  object@response <- c(object@response, NA, NA)
+  object@backfilled <- c(object@backfilled, FALSE, FALSE)
 
   expect_valid(result, "DataParts")
   expect_identical(result, object)
@@ -302,6 +366,8 @@ test_that("Update of DataDual works as expected", {
   object@ID <- c(object@ID, 13L, 14L)
   object@xLevel <- c(object@xLevel, 2L, 2L)
   object@cohort <- c(object@cohort, 4L, 4L)
+  object@response <- c(object@response, NA, NA)
+  object@backfilled <- c(object@backfilled, FALSE, FALSE)
 
   expect_valid(result, "DataDual")
   expect_identical(result, object)
@@ -328,6 +394,8 @@ test_that("Update of DataDA works as expected", {
   object@cohort <- c(object@cohort, 4L)
   object@t0 <- c(object@t0, 135)
   object@u <- c(42, 30, 15, 5, 20, 25, 30, 55, 25, 30, 20, 15, 5)
+  object@response <- c(object@response, NA)
+  object@backfilled <- c(object@backfilled, FALSE)
 
   expect_valid(result, "DataDA")
   expect_identical(result, object)
@@ -632,7 +700,9 @@ test_that("tidy-DataGeneral creates the correct tibble", {
     doseGrid = c(1, 3, 5, 10, 15, 20, 25, 40, 50, 80, 100),
     placebo = FALSE,
     ID = 1:3,
-    cohort = 1:3
+    cohort = 1:3,
+    response = c(1, NA, 0),
+    backfilled = c(FALSE, FALSE, TRUE)
   )
   expected <- tibble(
     ID = 1:3,
@@ -643,9 +713,12 @@ test_that("tidy-DataGeneral creates the correct tibble", {
     Placebo = FALSE,
     NObs = 3,
     NGrid = 11,
-    DoseGrid = list(c(1, 3, 5, 10, 15, 20, 25, 40, 50, 80, 100))
+    DoseGrid = list(c(1, 3, 5, 10, 15, 20, 25, 40, 50, 80, 100)),
+    Response = c(1, NA, 0),
+    Backfilled = c(FALSE, FALSE, TRUE)
   )
-  class(expected) <- c("tbl_Data", class(expected))
+  # Note that we need to set the class manually here and we need twice "tbl_Data".
+  class(expected) <- c("tbl_Data", "tbl_Data", class(expected))
 
   expect_equal(tidy(d), expected)
 
