@@ -105,7 +105,14 @@ test_that("Design object can be created with user constructor", {
 test_that("Design user constructor arguments names are as expected", {
   expect_function(
     Design,
-    args = c("model", "stopping", "increments", "pl_cohort_size", "..."),
+    args = c(
+      "model",
+      "stopping",
+      "increments",
+      "pl_cohort_size",
+      "backfill",
+      "..."
+    ),
     ordered = TRUE
   )
 })
@@ -419,14 +426,6 @@ test_that("DADesign constructor works as expected", {
   expect_true(identical(result@increments, increments))
 })
 
-test_that("DADesign user constructor arguments names are as expected", {
-  expect_function(
-    Design,
-    args = c("model", "stopping", "increments", "pl_cohort_size", "..."),
-    ordered = TRUE
-  )
-})
-
 # DesignGrouped ----
 
 test_that(".DesignGrouped works as expected", {
@@ -571,11 +570,3 @@ test_that("DesignOrdinal object can be created with user constructor", {
     CohortSizeOrdinal(2L, CohortSizeConst(2L))
   )
 })
-
-test_that("Design user constructor arguments names are as expected", {
-  expect_function(
-    Design,
-    args = c("model", "stopping", "increments", "pl_cohort_size", "..."),
-    ordered = TRUE
-  )
-})
